@@ -20,6 +20,7 @@ Server interface.
 """
 
 import base64
+import warnings
 
 from oslo_utils import encodeutils
 import six
@@ -51,6 +52,12 @@ CONSOLE_TYPE_PROTOCOL_MAPPING = {
     'webmks': 'mks'
 }
 
+ADD_REMOVE_FIXED_FLOATING_DEPRECATION_WARNING = _(
+    'The %s server action API is deprecated as of the 2.44 microversion. This '
+    'API binding will be removed in the first major release after the Nova '
+    '16.0.0 Pike release. Use python-neutronclient or openstacksdk instead.'
+)
+
 
 class Server(base.Resource):
     HUMAN_ID = True
@@ -871,29 +878,36 @@ class ServerManager(base.BootingManagerWithFind):
             marker = result[-1].id
         return result
 
+    @api_versions.wraps('2.0', '2.43')
     def add_fixed_ip(self, server, network_id):
         """
-        Add an IP address on a network.
+        DEPRECATED Add an IP address on a network.
 
         :param server: The :class:`Server` (or its ID) to add an IP to.
         :param network_id: The ID of the network the IP should be on.
         :returns: An instance of novaclient.base.TupleWithMeta
         """
+        warnings.warn(ADD_REMOVE_FIXED_FLOATING_DEPRECATION_WARNING %
+                      'addFixedIP', DeprecationWarning)
         return self._action('addFixedIp', server, {'networkId': network_id})
 
+    @api_versions.wraps('2.0', '2.43')
     def remove_fixed_ip(self, server, address):
         """
-        Remove an IP address.
+        DEPRECATED Remove an IP address.
 
         :param server: The :class:`Server` (or its ID) to add an IP to.
         :param address: The IP address to remove.
         :returns: An instance of novaclient.base.TupleWithMeta
         """
+        warnings.warn(ADD_REMOVE_FIXED_FLOATING_DEPRECATION_WARNING %
+                      'removeFixedIP', DeprecationWarning)
         return self._action('removeFixedIp', server, {'address': address})
 
+    @api_versions.wraps('2.0', '2.43')
     def add_floating_ip(self, server, address, fixed_address=None):
         """
-        Add a floating IP to an instance
+        DEPRECATED Add a floating IP to an instance
 
         :param server: The :class:`Server` (or its ID) to add an IP to.
         :param address: The FloatingIP or string floating address to add.
@@ -901,7 +915,8 @@ class ServerManager(base.BootingManagerWithFind):
                               associated with (optional)
         :returns: An instance of novaclient.base.TupleWithMeta
         """
-
+        warnings.warn(ADD_REMOVE_FIXED_FLOATING_DEPRECATION_WARNING %
+                      'addFloatingIP', DeprecationWarning)
         address = address.ip if hasattr(address, 'ip') else address
         if fixed_address:
             if hasattr(fixed_address, 'ip'):
@@ -912,15 +927,17 @@ class ServerManager(base.BootingManagerWithFind):
         else:
             return self._action('addFloatingIp', server, {'address': address})
 
+    @api_versions.wraps('2.0', '2.43')
     def remove_floating_ip(self, server, address):
         """
-        Remove a floating IP address.
+        DEPRECATED Remove a floating IP address.
 
         :param server: The :class:`Server` (or its ID) to remove an IP from.
         :param address: The FloatingIP or string floating address to remove.
         :returns: An instance of novaclient.base.TupleWithMeta
         """
-
+        warnings.warn(ADD_REMOVE_FIXED_FLOATING_DEPRECATION_WARNING %
+                      'removeFloatingIP', DeprecationWarning)
         address = address.ip if hasattr(address, 'ip') else address
         return self._action('removeFloatingIp', server, {'address': address})
 
@@ -1613,8 +1630,13 @@ class ServerManager(base.BootingManagerWithFind):
         body = {'name': image_name, 'metadata': metadata or {}}
         resp, body = self._action_return_resp_and_body('createImage', server,
                                                        body)
-        location = resp.headers['location']
-        image_uuid = location.split('/')[-1]
+        # The 2.45 microversion returns the image_id in the response body,
+        # not as a location header.
+        if self.api_version >= api_versions.APIVersion('2.45'):
+            image_uuid = body['image_id']
+        else:
+            location = resp.headers['location']
+            image_uuid = location.split('/')[-1]
         return base.StrWithMeta(image_uuid, resp)
 
     def backup(self, server, backup_name, backup_type, rotation):
@@ -1626,7 +1648,8 @@ class ServerManager(base.BootingManagerWithFind):
         :param backup_type: The backup type, like 'daily' or 'weekly'
         :param rotation: Int parameter representing how many backups to
                         keep around.
-        :returns: An instance of novaclient.base.TupleWithMeta
+        :returns: An instance of novaclient.base.TupleWithMeta if the request
+            microversion is < 2.45, otherwise novaclient.base.DictWithMeta.
         """
         body = {'name': backup_name,
                 'backup_type': backup_type,
